@@ -38,15 +38,20 @@ sub scan_word {
 	for (my $i = $startindex; $i < length(@tokenslist); $i++) {
 		if (@tokenslist[$i] == " ") {
 			push(%lexertablehash[$s], @rts);
-			$index = $i + 1; ### skip the whitespae itself
+			$index = $i + 1; ### skip the whitespace itself
+			$s = "";
 			last;
 		}
 		if (@tokenslist[$i] == "{") {
+			push(%lexertablehash[$s], @rts); ### push "bracein"
+			$s = "";
 			push(%lexertablehash["{"], @rts); ### push "bracein"
 			$index = $i + 1; 
 			last;
 		}
 		if (@tokenslist[$i] == "}") {
+			push(%lexertablehash[$s], @rts); ### push "bracein"
+			$s = "";
 			push(%lexertablehash["}"], @rts); ### push "braceout"
 			$index = $i + 1; 
 			last;
